==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-mount/translations/mount_es_UY.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_UY">
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.ui" line="44"/>
        <source>Click to access this device from other applications.</source>
        <translation>Presione para acceder a este dispositivo desde otras aplicaciones.</translation>
    </message>
    <message>
        <location filename="../menudiskitem.ui" line="57"/>
        <source>Click to eject this disc.</source>
        <translation>Presione para expulsar este disco.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <location filename="../mountbutton.cpp" line="185"/>
        <source>Removable media/devices manager</source>
        <translation>Administrador de dispositivos desmontables</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="280"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; está conectado.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="299"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; fue quitado.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="342"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is mounted to %2</source>
        <translation>El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; está montado en %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="356"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is unmounted&lt;br&gt;
Now you can eject USB Flash or CD/DVD Disk.</source>
        <translation>El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; está desmontado&lt;br&gt;
Ahora puede desconectar el disco USB o quitar el CD/DVD.</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="388"/>
        <source>Can&apos;t mount device: %1&lt;br&gt;
%2</source>
        <translation>No se puede montar el dispositivo: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="394"/>
        <source>Device &apos;%1&apos; is mounted to %2</source>
        <translation>El dispositivo &apos;%1&apos; está montado en %2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="424"/>
        <source>Can&apos;t unmount device: %1&lt;br&gt;
%2</source>
        <translation>No se puede desmontar el dispositivo: %1&lt;br&gt;
%2</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="428"/>
        <source>Device &apos;%1&apos; is unmounted</source>
        <translation>El dispositivo &apos;%1&apos; está desmontado</translation>
    </message>
    <message>
        <location filename="../mountbutton.cpp" line="444"/>
        <source>No devices Available.</source>
        <translation>No hay dispositivos disponibles.</translation>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <location filename="../razormountconfiguration.ui" line="14"/>
        <source>Razor Removable media manager settings</source>
        <translation>Configuración de dispositivos desmontables Razor</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.ui" line="26"/>
        <source>When a device is connected </source>
        <translation>Cuando un dispositivo es conectado</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="43"/>
        <source>Popup menu</source>
        <translation>Menú emergente</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="44"/>
        <source>Show info</source>
        <translation>Mostrar información</translation>
    </message>
    <message>
        <location filename="../razormountconfiguration.cpp" line="45"/>
        <source>Do nothing</source>
        <translation>No hacer nada</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-mount/translations/mount_es_UY.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_UY" version="2.0">
<context>
    <name>MenuDiskItem</name>
    <message>
        <source>Click to access this device from other applications.</source>
        <translation>Presione para acceder a este dispositivo desde otras aplicaciones.</translation>
    </message>
    <message>
        <source>Click to eject this disc.</source>
        <translation>Presione para expulsar este disco.</translation>
    </message>
</context>
<context>
    <name>MountButton</name>
    <message>
        <source>Removable media/devices manager</source>
        <translation>Administrador de dispositivos desmontables</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; está conectado.</translation>
    </message>
    <message>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>El dispositivo &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; fue quitado.</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <source>No devices are available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RazorMountConfiguration</name>
    <message>
        <source>Razor Removable media manager settings</source>
        <translation>Configuración de dispositivos desmontables Razor</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <source>When a device is connected </source>
        <translation>Cuando un dispositivo es conectado</translation>
    </message>
    <message>
        <source>Popup menu</source>
        <translation>Menú emergente</translation>
    </message>
    <message>
        <source>Show info</source>
        <translation>Mostrar información</translation>
    </message>
    <message>
        <source>Do nothing</source>
        <translation>No hacer nada</translation>
    </message>
</context>
</TS>
